@@ -1,10 +1,9 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 # test_cancel.py - unit test for query cancellation
 #
 # Copyright (C) 2010-2019 Jan Urbański  <wulczer@wulczer.org>
-# Copyright (C) 2020 The Psycopg Team
+# Copyright (C) 2020-2021 The Psycopg Team
 #
 # psycopg2 is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
@@ -34,6 +33,7 @@ from psycopg2 import extras
 from .testconfig import dsn
 import unittest
 from .testutils import ConnectingTestCase, skip_before_postgres, slow
+from .testutils import skip_if_crdb
 
 
 class CancelTests(ConnectingTestCase):
@@ -41,6 +41,8 @@ class CancelTests(ConnectingTestCase):
     def setUp(self):
         ConnectingTestCase.setUp(self)
 
+        skip_if_crdb("cancel", self.conn)
+
         cur = self.conn.cursor()
         cur.execute('''
             CREATE TEMPORARY TABLE table1 (
@@ -106,11 +108,6 @@ class CancelTests(ConnectingTestCase):
         extras.wait_select(async_conn)
         self.assertEqual(cur.fetchall(), [(1, )])
 
-    def test_async_connection_cancel(self):
-        async_conn = psycopg2.connect(dsn, async_=True)
-        async_conn.close()
-        self.assertTrue(async_conn.closed)
-
 
 def test_suite():
     return unittest.TestLoader().loadTestsFromName(__name__)
