@@ -3,7 +3,7 @@
 # extras_dictcursor - test if DictCursor extension class works
 #
 # Copyright (C) 2004-2019 Federico Di Gregorio  <fog@debian.org>
-# Copyright (C) 2020 The Psycopg Team
+# Copyright (C) 2020-2021 The Psycopg Team
 #
 # psycopg2 is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
@@ -20,14 +20,14 @@ import time
 import pickle
 import unittest
 from datetime import timedelta
+from functools import lru_cache
 
 import psycopg2
-from psycopg2.compat import lru_cache
 import psycopg2.extras
 from psycopg2.extras import NamedTupleConnection, NamedTupleCursor
 
 from .testutils import ConnectingTestCase, skip_before_postgres, \
-    skip_before_python, skip_from_python, crdb_version, skip_if_crdb
+    crdb_version, skip_if_crdb
 
 
 class _DictCursorBase(ConnectingTestCase):
@@ -64,7 +64,7 @@ class _DictCursorBase(ConnectingTestCase):
 class ExtrasDictCursorTests(_DictCursorBase):
     """Test if DictCursor extension class works."""
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     def testDictConnCursorArgs(self):
         self.conn.close()
         self.conn = self.connect(connection_factory=psycopg2.extras.DictConnection)
@@ -132,19 +132,19 @@ class ExtrasDictCursorTests(_DictCursorBase):
                 return row
         self._testWithNamedCursor(getter)
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("greedy cursor")
     @skip_before_postgres(8, 2)
     def testDictCursorWithNamedCursorNotGreedy(self):
         curs = self.conn.cursor('tmp', cursor_factory=psycopg2.extras.DictCursor)
         self._testNamedCursorNotGreedy(curs)
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     @skip_before_postgres(8, 0)
     def testDictCursorWithNamedCursorIterRowNumber(self):
         curs = self.conn.cursor('tmp', cursor_factory=psycopg2.extras.DictCursor)
         self._testIterRowNumber(curs)
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     def _testWithNamedCursor(self, getter):
         curs = self.conn.cursor('aname', cursor_factory=psycopg2.extras.DictCursor)
         curs.execute("SELECT * FROM ExtrasDictCursorTests")
@@ -179,27 +179,7 @@ class ExtrasDictCursorTests(_DictCursorBase):
         self.assertEqual(len(rv3), 2)
         self.assertEqual(len(rv), 2)
 
-    @skip_from_python(3)
-    def test_iter_methods_2(self):
-        curs = self.conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
-        curs.execute("select 10 as a, 20 as b")
-        r = curs.fetchone()
-        self.assert_(isinstance(r.keys(), list))
-        self.assertEqual(len(r.keys()), 2)
-        self.assert_(isinstance(r.values(), tuple))     # sic?
-        self.assertEqual(len(r.values()), 2)
-        self.assert_(isinstance(r.items(), list))
-        self.assertEqual(len(r.items()), 2)
-
-        self.assert_(not isinstance(r.iterkeys(), list))
-        self.assertEqual(len(list(r.iterkeys())), 2)
-        self.assert_(not isinstance(r.itervalues(), list))
-        self.assertEqual(len(list(r.itervalues())), 2)
-        self.assert_(not isinstance(r.iteritems(), list))
-        self.assertEqual(len(list(r.iteritems())), 2)
-
-    @skip_before_python(3)
-    def test_iter_methods_3(self):
+    def test_iter_methods(self):
         curs = self.conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
         curs.execute("select 10 as a, 20 as b")
         r = curs.fetchone()
@@ -226,21 +206,6 @@ class ExtrasDictCursorTests(_DictCursorBase):
         self.assertEqual(list(r1.values()), list(r.values()))
         self.assertEqual(list(r1.items()), list(r.items()))
 
-    @skip_from_python(3)
-    def test_order_iter(self):
-        curs = self.conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
-        curs.execute("select 5 as foo, 4 as bar, 33 as baz, 2 as qux")
-        r = curs.fetchone()
-        self.assertEqual(list(r.iterkeys()), ['foo', 'bar', 'baz', 'qux'])
-        self.assertEqual(list(r.itervalues()), [5, 4, 33, 2])
-        self.assertEqual(list(r.iteritems()),
-            [('foo', 5), ('bar', 4), ('baz', 33), ('qux', 2)])
-
-        r1 = pickle.loads(pickle.dumps(r))
-        self.assertEqual(list(r1.iterkeys()), list(r.iterkeys()))
-        self.assertEqual(list(r1.itervalues()), list(r.itervalues()))
-        self.assertEqual(list(r1.iteritems()), list(r.iteritems()))
-
 
 class ExtrasDictCursorRealTests(_DictCursorBase):
     def testRealMeansReal(self):
@@ -320,19 +285,19 @@ class ExtrasDictCursorRealTests(_DictCursorBase):
                 return row
         self._testWithNamedCursorReal(getter)
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("greedy cursor")
     @skip_before_postgres(8, 2)
     def testDictCursorRealWithNamedCursorNotGreedy(self):
         curs = self.conn.cursor('tmp', cursor_factory=psycopg2.extras.RealDictCursor)
         self._testNamedCursorNotGreedy(curs)
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     @skip_before_postgres(8, 0)
     def testDictCursorRealWithNamedCursorIterRowNumber(self):
         curs = self.conn.cursor('tmp', cursor_factory=psycopg2.extras.RealDictCursor)
         self._testIterRowNumber(curs)
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     def _testWithNamedCursorReal(self, getter):
         curs = self.conn.cursor('aname',
             cursor_factory=psycopg2.extras.RealDictCursor)
@@ -340,27 +305,7 @@ class ExtrasDictCursorRealTests(_DictCursorBase):
         row = getter(curs)
         self.failUnless(row['foo'] == 'bar')
 
-    @skip_from_python(3)
-    def test_iter_methods_2(self):
-        curs = self.conn.cursor(cursor_factory=psycopg2.extras.RealDictCursor)
-        curs.execute("select 10 as a, 20 as b")
-        r = curs.fetchone()
-        self.assert_(isinstance(r.keys(), list))
-        self.assertEqual(len(r.keys()), 2)
-        self.assert_(isinstance(r.values(), list))
-        self.assertEqual(len(r.values()), 2)
-        self.assert_(isinstance(r.items(), list))
-        self.assertEqual(len(r.items()), 2)
-
-        self.assert_(not isinstance(r.iterkeys(), list))
-        self.assertEqual(len(list(r.iterkeys())), 2)
-        self.assert_(not isinstance(r.itervalues(), list))
-        self.assertEqual(len(list(r.itervalues())), 2)
-        self.assert_(not isinstance(r.iteritems(), list))
-        self.assertEqual(len(list(r.iteritems())), 2)
-
-    @skip_before_python(3)
-    def test_iter_methods_3(self):
+    def test_iter_methods(self):
         curs = self.conn.cursor(cursor_factory=psycopg2.extras.RealDictCursor)
         curs.execute("select 10 as a, 20 as b")
         r = curs.fetchone()
@@ -387,21 +332,6 @@ class ExtrasDictCursorRealTests(_DictCursorBase):
         self.assertEqual(list(r1.values()), list(r.values()))
         self.assertEqual(list(r1.items()), list(r.items()))
 
-    @skip_from_python(3)
-    def test_order_iter(self):
-        curs = self.conn.cursor(cursor_factory=psycopg2.extras.RealDictCursor)
-        curs.execute("select 5 as foo, 4 as bar, 33 as baz, 2 as qux")
-        r = curs.fetchone()
-        self.assertEqual(list(r.iterkeys()), ['foo', 'bar', 'baz', 'qux'])
-        self.assertEqual(list(r.itervalues()), [5, 4, 33, 2])
-        self.assertEqual(list(r.iteritems()),
-            [('foo', 5), ('bar', 4), ('baz', 33), ('qux', 2)])
-
-        r1 = pickle.loads(pickle.dumps(r))
-        self.assertEqual(list(r1.iterkeys()), list(r.iterkeys()))
-        self.assertEqual(list(r1.itervalues()), list(r.itervalues()))
-        self.assertEqual(list(r1.iteritems()), list(r.iteritems()))
-
     def test_pop(self):
         curs = self.conn.cursor(cursor_factory=psycopg2.extras.RealDictCursor)
         curs.execute("select 1 as a, 2 as b, 3 as c")
@@ -446,7 +376,7 @@ class NamedTupleCursorTest(ConnectingTestCase):
         curs.execute("INSERT INTO nttest VALUES (3, 'baz')")
         self.conn.commit()
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     def test_cursor_args(self):
         cur = self.conn.cursor('foo', cursor_factory=psycopg2.extras.DictCursor)
         self.assertEqual(cur.name, 'foo')
@@ -564,7 +494,6 @@ class NamedTupleCursorTest(ConnectingTestCase):
         self.assertEqual(rv.f_column_, 2)
         self.assertEqual(rv.f3, 3)
 
-    @skip_before_python(3)
     @skip_before_postgres(8)
     def test_nonascii_name(self):
         curs = self.conn.cursor()
@@ -604,7 +533,7 @@ class NamedTupleCursorTest(ConnectingTestCase):
         finally:
             NamedTupleCursor._make_nt = f_orig
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     @skip_before_postgres(8, 0)
     def test_named(self):
         curs = self.conn.cursor('tmp')
@@ -615,28 +544,28 @@ class NamedTupleCursorTest(ConnectingTestCase):
         recs.extend(curs.fetchall())
         self.assertEqual(list(range(10)), [t.i for t in recs])
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     def test_named_fetchone(self):
         curs = self.conn.cursor('tmp')
         curs.execute("""select 42 as i""")
         t = curs.fetchone()
         self.assertEqual(t.i, 42)
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     def test_named_fetchmany(self):
         curs = self.conn.cursor('tmp')
         curs.execute("""select 42 as i""")
         recs = curs.fetchmany(10)
         self.assertEqual(recs[0].i, 42)
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     def test_named_fetchall(self):
         curs = self.conn.cursor('tmp')
         curs.execute("""select 42 as i""")
         recs = curs.fetchall()
         self.assertEqual(recs[0].i, 42)
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("greedy cursor")
     @skip_before_postgres(8, 2)
     def test_not_greedy(self):
         curs = self.conn.cursor('tmp')
@@ -651,7 +580,7 @@ class NamedTupleCursorTest(ConnectingTestCase):
         self.assert_(recs[1].ts - recs[0].ts < timedelta(seconds=0.005))
         self.assert_(recs[2].ts - recs[1].ts > timedelta(seconds=0.0099))
 
-    @skip_if_crdb("named cursor")
+    @skip_if_crdb("named cursor", version="< 22.1")
     @skip_before_postgres(8, 0)
     def test_named_rownumber(self):
         curs = self.conn.cursor('tmp')
@@ -692,7 +621,7 @@ class NamedTupleCursorTest(ConnectingTestCase):
             recs = []
             curs = self.conn.cursor()
             for i in range(10):
-                curs.execute("select 1 as f%s" % i)
+                curs.execute(f"select 1 as f{i}")
                 recs.append(curs.fetchone())
 
             # Still in cache
