@@ -3,10 +3,10 @@
 import os
 
 dbname = os.environ.get('PSYCOPG2_TESTDB', 'psycopg2_test')
-dbhost = os.environ.get('PSYCOPG2_TESTDB_HOST', None)
-dbport = os.environ.get('PSYCOPG2_TESTDB_PORT', None)
-dbuser = os.environ.get('PSYCOPG2_TESTDB_USER', None)
-dbpass = os.environ.get('PSYCOPG2_TESTDB_PASSWORD', None)
+dbhost = os.environ.get('PSYCOPG2_TESTDB_HOST', os.environ.get('PGHOST'))
+dbport = os.environ.get('PSYCOPG2_TESTDB_PORT', os.environ.get('PGPORT'))
+dbuser = os.environ.get('PSYCOPG2_TESTDB_USER', os.environ.get('PGUSER'))
+dbpass = os.environ.get('PSYCOPG2_TESTDB_PASSWORD', os.environ.get('PGPASSWORD'))
 
 # Check if we want to test psycopg's green path.
 green = os.environ.get('PSYCOPG2_TEST_GREEN', None)
@@ -23,15 +23,15 @@ if green:
     psycopg2.extensions.set_wait_callback(wait_callback)
 
 # Construct a DSN to connect to the test database:
-dsn = 'dbname=%s' % dbname
+dsn = f'dbname={dbname}'
 if dbhost is not None:
-    dsn += ' host=%s' % dbhost
+    dsn += f' host={dbhost}'
 if dbport is not None:
-    dsn += ' port=%s' % dbport
+    dsn += f' port={dbport}'
 if dbuser is not None:
-    dsn += ' user=%s' % dbuser
+    dsn += f' user={dbuser}'
 if dbpass is not None:
-    dsn += ' password=%s' % dbpass
+    dsn += f' password={dbpass}'
 
 # Don't run replication tests if REPL_DSN is not set, default to normal DSN if
 # set to empty string.
