@@ -2,7 +2,7 @@
 
 #
 # Copyright (C) 2010-2019 Daniele Varrazzo  <daniele.varrazzo@gmail.com>
-# Copyright (C) 2020 The Psycopg Team
+# Copyright (C) 2020-2021 The Psycopg Team
 #
 # psycopg2 is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published
@@ -29,36 +29,21 @@ import sys
 import types
 import ctypes
 import select
+import operator
 import platform
 import unittest
 from functools import wraps
 from ctypes.util import find_library
+from io import StringIO         # noqa
+from io import TextIOBase       # noqa
+from importlib import reload    # noqa
 
 import psycopg2
 import psycopg2.errors
 import psycopg2.extensions
-from psycopg2.compat import PY2, PY3, text_type
 
 from .testconfig import green, dsn, repl_dsn
 
-# Python 2/3 compatibility
-
-if PY2:
-    # Python 2
-    from StringIO import StringIO
-    TextIOBase = object
-    long = long
-    reload = reload
-    unichr = unichr
-
-else:
-    # Python 3
-    from io import StringIO         # noqa
-    from io import TextIOBase       # noqa
-    from importlib import reload    # noqa
-    long = int
-    unichr = chr
-
 
 # Silence warnings caused by the stubbornness of the Python unittest
 # maintainers
@@ -101,7 +86,7 @@ class ConnectingTestCase(unittest.TestCase):
     def assertQuotedEqual(self, first, second, msg=None):
         """Compare two quoted strings disregarding eventual E'' quotes"""
         def f(s):
-            if isinstance(s, text_type):
+            if isinstance(s, str):
                 return re.sub(r"\bE'", "'", s)
             elif isinstance(first, bytes):
                 return re.sub(br"\bE'", b"'", s)
@@ -115,8 +100,7 @@ class ConnectingTestCase(unittest.TestCase):
             self._conns
         except AttributeError as e:
             raise AttributeError(
-                "%s (did you forget to call ConnectingTestCase.setUp()?)"
-                % e)
+                f"{e} (did you forget to call ConnectingTestCase.setUp()?)")
 
         if 'dsn' in kwargs:
             conninfo = kwargs.pop('dsn')
@@ -149,7 +133,7 @@ class ConnectingTestCase(unittest.TestCase):
             # Otherwise we tried to run some bad operation in the connection
             # (e.g. bug #482) and we'd rather know that.
             if e.pgcode is None:
-                return self.skipTest("replication db not configured: %s" % e)
+                return self.skipTest(f"replication db not configured: {e}")
             else:
                 raise
 
@@ -194,7 +178,10 @@ class ConnectingTestCase(unittest.TestCase):
         if libname is None and platform.system() == 'Windows':
             raise self.skipTest("can't import libpq on windows")
 
-        rv = ConnectingTestCase._libpq = ctypes.pydll.LoadLibrary(libname)
+        try:
+            rv = ConnectingTestCase._libpq = ctypes.pydll.LoadLibrary(libname)
+        except OSError as e:
+            raise self.skipTest("couldn't open libpq for testing: %s" % e)
         return rv
 
 
@@ -248,6 +235,8 @@ def skip_if_tpc_disabled(f):
     @wraps(f)
     def skip_if_tpc_disabled_(self):
         cnn = self.connect()
+        skip_if_crdb("2-phase commit", cnn)
+
         cur = cnn.cursor()
         try:
             cur.execute("SHOW max_prepared_transactions;")
@@ -323,7 +312,7 @@ def skip_before_libpq(*ver):
         v = libpq_version()
         decorator = unittest.skipIf(
             v < int("%d%02d%02d" % ver),
-            "skipped because libpq %d" % v,
+            f"skipped because libpq {v}",
         )
         return decorator(cls)
     return skip_before_libpq_
@@ -337,7 +326,7 @@ def skip_after_libpq(*ver):
         v = libpq_version()
         decorator = unittest.skipIf(
             v >= int("%d%02d%02d" % ver),
-            "skipped because libpq %s" % v,
+            f"skipped because libpq {v}",
         )
         return decorator(cls)
     return skip_after_libpq_
@@ -348,8 +337,7 @@ def skip_before_python(*ver):
     def skip_before_python_(cls):
         decorator = unittest.skipIf(
             sys.version_info[:len(ver)] < ver,
-            "skipped because Python %s"
-            % ".".join(map(str, sys.version_info[:len(ver)])),
+            f"skipped because Python {'.'.join(map(str, sys.version_info[:len(ver)]))}",
         )
         return decorator(cls)
     return skip_before_python_
@@ -360,8 +348,7 @@ def skip_from_python(*ver):
     def skip_from_python_(cls):
         decorator = unittest.skipIf(
             sys.version_info[:len(ver)] >= ver,
-            "skipped because Python %s"
-            % ".".join(map(str, sys.version_info[:len(ver)])),
+            f"skipped because Python {'.'.join(map(str, sys.version_info[:len(ver)]))}",
         )
         return decorator(cls)
     return skip_from_python_
@@ -407,14 +394,125 @@ def skip_if_windows(cls):
     return decorator(cls)
 
 
-class py3_raises_typeerror(object):
+def crdb_version(conn, __crdb_version=[]):
+    """
+    Return the CockroachDB version if that's the db being tested, else None.
+
+    Return the number as an integer similar to PQserverVersion: return
+    v20.1.3 as 200103.
+
+    Assume all the connections are on the same db: return a cached result on
+    following calls.
+
+    """
+    if __crdb_version:
+        return __crdb_version[0]
+
+    sver = conn.info.parameter_status("crdb_version")
+    if sver is None:
+        __crdb_version.append(None)
+    else:
+        m = re.search(r"\bv(\d+)\.(\d+)\.(\d+)", sver)
+        if not m:
+            raise ValueError(
+                f"can't parse CockroachDB version from {sver}")
+
+        ver = int(m.group(1)) * 10000 + int(m.group(2)) * 100 + int(m.group(3))
+        __crdb_version.append(ver)
+
+    return __crdb_version[0]
+
+
+def skip_if_crdb(reason, conn=None, version=None):
+    """Skip a test or test class if we are testing against CockroachDB.
+
+    Can be used as a decorator for tests function or classes:
+
+        @skip_if_crdb("my reason")
+        class SomeUnitTest(UnitTest):
+            # ...
+
+    Or as a normal function if the *conn* argument is passed.
+
+    If *version* is specified it should be a string such as ">= 20.1", "< 20",
+    "== 20.1.3": the test will be skipped only if the version matches.
+
+    """
+    if not isinstance(reason, str):
+        raise TypeError(f"reason should be a string, got {reason!r} instead")
+
+    if conn is not None:
+        ver = crdb_version(conn)
+        if ver is not None and _crdb_match_version(ver, version):
+            if reason in crdb_reasons:
+                reason = (
+                    "%s (https://github.com/cockroachdb/cockroach/issues/%s)"
+                    % (reason, crdb_reasons[reason]))
+            raise unittest.SkipTest(
+                f"not supported on CockroachDB {ver}: {reason}")
+
+    @decorate_all_tests
+    def skip_if_crdb_(f):
+        @wraps(f)
+        def skip_if_crdb__(self, *args, **kwargs):
+            skip_if_crdb(reason, conn=self.connect(), version=version)
+            return f(self, *args, **kwargs)
+
+        return skip_if_crdb__
+
+    return skip_if_crdb_
+
+
+# mapping from reason description to ticket number
+crdb_reasons = {
+    "2-phase commit": 22329,
+    "backend pid": 35897,
+    "batch statements": 44803,
+    "cancel": 41335,
+    "cast adds tz": 51692,
+    "cidr": 18846,
+    "composite": 27792,
+    "copy": 41608,
+    "cursor with hold": 77101,
+    "deferrable": 48307,
+    "encoding": 35882,
+    "hstore": 41284,
+    "infinity date": 41564,
+    "interval style": 35807,
+    "large objects": 243,
+    "named cursor": 41412,
+    "nested array": 32552,
+    "notify": 41522,
+    "password_encryption": 42519,
+    "range": 41282,
+    "scroll cursor": 77102,
+    "stored procedure": 1751,
+}
+
+
+def _crdb_match_version(version, pattern):
+    if pattern is None:
+        return True
+
+    m = re.match(r'^(>|>=|<|<=|==|!=)\s*(\d+)(?:\.(\d+))?(?:\.(\d+))?$', pattern)
+    if m is None:
+        raise ValueError(
+            "bad crdb version pattern %r: should be 'OP MAJOR[.MINOR[.BUGFIX]]'"
+            % pattern)
+
+    ops = {'>': 'gt', '>=': 'ge', '<': 'lt', '<=': 'le', '==': 'eq', '!=': 'ne'}
+    op = getattr(operator, ops[m.group(1)])
+    ref = int(m.group(2)) * 10000 + int(m.group(3) or 0) * 100 + int(m.group(4) or 0)
+    return op(version, ref)
+
+
+class raises_typeerror:
     def __enter__(self):
         pass
 
     def __exit__(self, type, exc, tb):
-        if PY3:
-            assert type is TypeError
-            return True
+        assert type is TypeError
+        return True
 
 
 def slow(f):
